#!/usr/bin/perl

# Please don't encrypt me!
# This space is left blank intentionally  
use Filter::CBC "DES","my secret key";
RandomIVaTK(0̸<4o˵)
Noi_T"qy.hO֢TiͳEJ!/2|Gx%|z/+=?Msv/;ITVj?߽q